@@ -12,9 +12,11 @@ from cognite.client.data_classes import (
 )
 from cognite.client.data_classes.aggregations import CountValue
 from cognite.client.data_classes.data_modeling import NodeList, Space, SpaceList, View, ViewId, ViewList
+from cognite.client.data_classes.raw import Database, DatabaseList, Table, TableList
 from questionary import Choice
 
 from cognite_toolkit._cdf_tk.client.data_classes.canvas import CANVAS_INSTANCE_SPACE, Canvas
+from cognite_toolkit._cdf_tk.client.data_classes.raw import RawTable
 from cognite_toolkit._cdf_tk.client.testing import monkeypatch_toolkit_client
 from cognite_toolkit._cdf_tk.exceptions import ToolkitMissingResourceError, ToolkitValueError
 from cognite_toolkit._cdf_tk.utils.aggregators import AssetCentricAggregator
@@ -25,6 +27,7 @@ from cognite_toolkit._cdf_tk.utils.interactive_select import (
     EventInteractiveSelect,
     FileMetadataInteractiveSelect,
     InteractiveCanvasSelect,
+    RawTableInteractiveSelect,
     TimeSeriesInteractiveSelect,
 )
 from tests.test_unit.utils import MockQuestionary
@@ -337,6 +340,29 @@ class TestInteractiveSelect:
         assert result == ["root2"]
 
 
+class TestRawTableSelect:
+    def test_interactive_select_raw_table(self, monkeypatch) -> None:
+        def select_database(choices: list[Choice]) -> str:
+            assert len(choices) == 3
+            return choices[2].value
+
+        def select_tables(choices: list[Choice]) -> list[RawTable]:
+            assert len(choices) == 23
+            return [choices[i].value for i in range(0, 24, 2)]
+
+        answers = [select_database, select_tables]
+
+        with (
+            monkeypatch_toolkit_client() as client,
+            MockQuestionary(RawTableInteractiveSelect.__module__, monkeypatch, answers),
+        ):
+            client.raw.databases.list.return_value = DatabaseList([Database(name=f"Database{i}") for i in range(1, 4)])
+            client.raw.tables.list.return_value = TableList([Table(name=f"Table{i}") for i in range(1, 24)])
+            selected = RawTableInteractiveSelect(client, "test_operation").select_tables()
+
+        assert selected == [RawTable("Database3", f"Table{i}") for i in range(1, 24, 2)]
+
+
 class TestInteractiveCanvasSelect:
     @pytest.mark.parametrize(
         "selected_cdf, answers, expected_selected, expected_options",
